@@ -182,6 +182,9 @@ INVALIDPARAMETER_FORMATERROR = 'InvalidParameter.FormatError'
 # 参数取值错误。
 INVALIDPARAMETERVALUE = 'InvalidParameterValue'
 
+# 插件定义参数取值重复，请修改后重新操作。
+INVALIDPARAMETERVALUE_DUPLICATEPLUGINCONFIG = 'InvalidParameterValue.DuplicatePluginConfig'
+
 # 密钥错误。
 INVALIDPARAMETERVALUE_INVALIDACCESSKEYIDS = 'InvalidParameterValue.InvalidAccessKeyIds'
 
@@ -302,7 +305,7 @@ LIMITEXCEEDED = 'LimitExceeded'
 # API文档数量超出限制。
 LIMITEXCEEDED_APIDOCLIMITEXCEEDED = 'LimitExceeded.APIDocLimitExceeded'
 
-# 应用数量超过限制。
+# 服务绑定的应用数量超过限制。
 LIMITEXCEEDED_APIAPPCOUNTLIMITEXCEEDED = 'LimitExceeded.ApiAppCountLimitExceeded'
 
 # API数量超过限制。
@@ -401,6 +404,9 @@ UNSUPPORTEDOPERATION = 'UnsupportedOperation'
 # 密钥已绑定使用计划。
 UNSUPPORTEDOPERATION_ALREADYBINDUSAGEPLAN = 'UnsupportedOperation.AlreadyBindUsagePlan'
 
+# 当前插件不支持绑定。
+UNSUPPORTEDOPERATION_ATTACHPLUGIN = 'UnsupportedOperation.AttachPlugin'
+
 # 协议为HTTP时，不支持强制Https。
 UNSUPPORTEDOPERATION_FORCEHTTPS = 'UnsupportedOperation.ForceHttps'
 
@@ -410,6 +416,9 @@ UNSUPPORTEDOPERATION_INVALIDACTION = 'UnsupportedOperation.InvalidAction'
 # 不支持后端类型。
 UNSUPPORTEDOPERATION_INVALIDENDPOINTTYPE = 'UnsupportedOperation.InvalidEndpointType'
 
+# 当前实例状态，不支持当前操作。
+UNSUPPORTEDOPERATION_INVALIDINSTANCESTATE = 'UnsupportedOperation.InvalidInstanceState'
+
 # 当前服务处于隔离中，暂不支持此操作。
 UNSUPPORTEDOPERATION_INVALIDSERVICETRADE = 'UnsupportedOperation.InvalidServiceTrade'
 
@@ -419,6 +428,9 @@ UNSUPPORTEDOPERATION_INVALIDSTATUS = 'UnsupportedOperation.InvalidStatus'
 # 不支持修改EIAM类型授权API。
 UNSUPPORTEDOPERATION_MODIFYEIAMAUTHAPI = 'UnsupportedOperation.ModifyEIAMAuthApi'
 
+# 网络类型不支持修改。
+UNSUPPORTEDOPERATION_MODIFYNETTYPE = 'UnsupportedOperation.ModifyNetType'
+
 # 前端协议类型不支持修改。
 UNSUPPORTEDOPERATION_MODIFYPROTOCOL = 'UnsupportedOperation.ModifyProtocol'
 
